#!/bin/bash

#
PLATFORM=$1
#
INSTALL_PATH=
NIC_CONFIG_PATH=${INSTALL_PATH}/etc/pear/pear_monitor/nic.conf
MAC_CONFIG_PATH=${INSTALL_PATH}/etc/pear/pear_monitor/mac.conf
DISK_CONFIG_PATH=${INSTALL_PATH}/etc/pear/pear_monitor/dev.conf
PLATFORM_CONFIG_PATH=${INSTALL_PATH}/etc/pear/pear_docker/docker_platform.conf
CACHE_CONF_PATH=${INSTALL_PATH}/etc/pear/pear_docker/docker_cache_tv.conf
LOG_PATH=/tmp/check_config.log

declare -a mapping_path_list
gen_disk_config_folders() {
  # 
  docker_number=$1
  # 
  sata_list="/sata*"
  sata_array=(${sata_list})
  disk_number=${#sata_array[@]}
  echo "total disk number ${disk_number}"
  # 
  quota=$(($docker_number / $disk_number + 1))
  # 
  for j in $(seq 1 $quota); do
    for i in $(seq 1 $disk_number); do
      path="${sata_array[$i - 1]}/$j"
      # echo ${path}
      mkdir -p ${path}
      mapping_path_list[${#mapping_path_list[@]}]=${path}
    done
  done
}

check_disk_config() {
  # 
  docker_number=$1
  # note: folders that be made will be more than docker_number
  gen_disk_config_folders ${docker_number}
  # 
  content=""
  for i in $(seq 1 ${docker_number}); do
    if [[ -z ${content} ]]; then
      content=${mapping_path_list[$(($i - 1))]}
    else
      content=${content},${mapping_path_list[$(($i - 1))]}
    fi
  done
  # 
  # echo ${content}
  echo ${content} > ${DISK_CONFIG_PATH}
}

check_platform_config() {
  # 
  docker_number=$1
  #
  content=""
  for i in $(seq 1 ${docker_number}); do
    if [[ -z ${content} ]]; then
      content=${PLATFORM}
    else
      content=${content},${PLATFORM}
    fi
  done
  #
  # echo ${content}
  echo ${content} > ${PLATFORM_CONFIG_PATH}
}

check_cache_size_config() {
  # 
  docker_number=$1
  disks_total_size=0
  # calculate total /sata* size
  disks=`lsblk | grep disk | grep -v loop | awk '{system("echo /dev/" $1)}'`
  for disk in ${disks[@]}; do
    # check disk is valid
    output_result=`fdisk -l ${disk}`
    if [[ -z ${output_result} ]]; then
      error_result=`fdisk -l ${disk} 2>&1`
      echo "disk "${disk} " read error: ${error_result}"
      continue
    fi  
    disk_size=`lsblk ${disk} -b -o SIZE | grep -m 1 -vi SIZE`
    disk_size=$((${disk_size} / 1024 / 1024 / 1024))
    disks_total_size=$((${disks_total_size} + ${disk_size}))
    echo "${disk} size: ${disk_size}G"
  done
  cache_size=$(($disks_total_size * 9 / 10 / $docker_number))
  echo "total disk size: ${disks_total_size}G, each cache size: ${cache_size}"

  #
  echo ${cache_size} > ${CACHE_CONF_PATH}
}

docker_number=0
get_docker_number() {
  nic_list=`cat ${NIC_CONFIG_PATH} | sed 's/,/ /g'`
  nic_array_conf=(${nic_list})
  docker_number=${#nic_array_conf[@]}
  # echo ${docker_number}
}

#
datetime=`date "+%Y-%m-%d %H:%M:%S"`
echo "${datetime} [INFO ] start checking config" >> ${LOG_PATH}

# 
get_docker_number
check_disk_config ${docker_number}
check_platform_config ${docker_number}
if [[ ! -f ${CACHE_CONF_PATH} ]]; then
  check_cache_size_config ${docker_number}
fi

#
datetime=`date "+%Y-%m-%d %H:%M:%S"`
echo "${datetime} [INFO ] finish checking config" >> ${LOG_PATH}
